import { QueryOrchestrator, DriverFactoryByDataSource, DriverType, QueryOrchestratorOptions } from '@cubejs-backend/query-orchestrator';
import { DbTypeAsyncFn, ExternalDbTypeFn, RequestContext } from './types';
export interface OrchestratorApiOptions extends QueryOrchestratorOptions {
    contextToDbType: DbTypeAsyncFn;
    contextToExternalDbType: ExternalDbTypeFn;
    redisPrefix?: string;
}
export declare class OrchestratorApi {
    protected readonly driverFactory: DriverFactoryByDataSource;
    protected readonly logger: any;
    protected readonly options: OrchestratorApiOptions;
    private seenDataSources;
    protected readonly orchestrator: QueryOrchestrator;
    protected readonly continueWaitTimeout: number;
    constructor(driverFactory: DriverFactoryByDataSource, logger: any, options: OrchestratorApiOptions);
    /**
     * Returns QueryOrchestrator instance.
     */
    getQueryOrchestrator(): QueryOrchestrator;
    /**
     * Force reconcile queue logic to be executed.
     */
    forceReconcile(datasource?: string): Promise<void>;
    executeQuery(query: any): Promise<any>;
    testOrchestratorConnections(): Promise<void>;
    /**
     * Tests worker's connections to the Cubstore and, if not in the rollup only
     * mode, to the datasources.
     */
    testConnection(): Promise<void[]>;
    /**
     * Tests connection to the data source specified by the driver factory
     * function and data source name.
     */
    testDriverConnection(driverFn?: DriverFactoryByDataSource, driverType?: DriverType, dataSource?: string): Promise<void>;
    release(): Promise<void[]>;
    protected releaseDriver(driverFn?: DriverFactoryByDataSource, dataSource?: string): Promise<void>;
    addDataSeenSource(dataSource: any): void;
    getPreAggregationVersionEntries(context: RequestContext, preAggregations: any, preAggregationsSchema: any): Promise<{
        structureVersionsByTableName: any;
        versionEntriesByTableName: any;
    }>;
    getPreAggregationPreview(context: RequestContext, preAggregation: any): Promise<any>;
    expandPartitionsInPreAggregations(queryBody: any): Promise<import("@cubejs-backend/query-orchestrator").Query>;
    checkPartitionsBuildRangeCache(queryBody: any): Promise<[unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown, unknown]>;
    getPreAggregationQueueStates(): Promise<any[]>;
    cancelPreAggregationQueriesFromQueue(queryKeys: string[], dataSource: string): Promise<boolean[]>;
    subscribeQueueEvents(id: any, callback: any): Promise<void>;
    unSubscribeQueueEvents(id: any): Promise<void>;
}
//# sourceMappingURL=OrchestratorApi.d.ts.map